@@ -1,10 +1,7 @@
 ﻿import time
 import progressbar
 import threading
-import requests
 import re
-from bs4 import BeautifulSoup
-from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
 try:
     from . import data_type
@@ -30,7 +27,6 @@ except ModuleNotFoundError:
     import command
     import check_value
     import version
-requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
 
 
 class API:
@@ -195,6 +191,7 @@ class API:
         self._LastThrowWaterBallTime = 0
         self._ThreadID = threading.get_ident()
         self._goto_board_list = list()
+        self._board_info_list = dict()
 
         log.show_value(
             self.config,
@@ -435,8 +432,7 @@ class API:
                     search_type,
                     search_condition,
                     search_list,
-                    query
-                )
+                    query)
             except exceptions.ParseError as e:
                 if i == 1:
                     raise e
@@ -463,8 +459,7 @@ class API:
                 log.log(
                     self.config,
                     log.level.DEBUG,
-                    'Wait for retry repost'
-                )
+                    'Wait for retry repost')
                 time.sleep(0.1)
                 continue
 
@@ -474,7 +469,7 @@ class API:
     def _check_board(
             self,
             board: str,
-            check_moderator: bool = False) -> None:
+            check_moderator: bool = False) -> data_type.BoardInfo:
 
         if board.lower() not in self._exist_board_list:
             board_info = self._get_board_info(board, False)
@@ -484,11 +479,14 @@ class API:
             moderators = board_info.moderators
             moderators = [x.lower() for x in moderators]
             self._ModeratorList[board.lower()] = moderators
+            self._board_info_list[board.lower()] = board_info
 
         if check_moderator:
             if self._ID.lower() not in self._ModeratorList[board.lower()]:
                 raise exceptions.NeedModeratorPermission(board)
 
+        return self._board_info_list[board.lower()]
+
     def _get_post(
             self,
             board: str,
@@ -669,8 +667,7 @@ class API:
                     data_type.index_type.BBS,
                     board=board,
                     search_type=search_type,
-                    search_condition=search_condition
-                )
+                    search_condition=search_condition)
 
                 check_value.check_index_range(
                     self.config,
@@ -678,8 +675,7 @@ class API:
                     start_index,
                     'end_index',
                     end_index,
-                    max_value=newest_index
-                )
+                    max_value=newest_index)
             elif start_aid is not None and end_aid is not None:
                 start_index = self.get_post(
                     board,
@@ -823,110 +819,110 @@ class API:
             return error_post_list, del_post_list
 
         else:
-            if self.config.host == data_type.host_type.PTT2:
-                raise exceptions.HostNotSupport(lib_util.get_current_func_name())
-
-            # 網頁版本爬蟲
-            # https://www.ptt.cc/bbs/index.html
-
-            # 1. 取得總共有幾頁 MaxPage
-            newest_index = self._get_newest_index(
-                data_type.index_type.WEB,
-                board=board)
-            # 2. 檢查 StartPage 跟 EndPage 有沒有在 1 ~ MaxPage 之間
-
-            check_value.check_index_range(
-                self.config,
-                'StartPage',
-                start_page,
-                'EndPage',
-                end_page,
-                max_value=newest_index
-            )
-
-            # 3. 把每篇文章(包括被刪除文章)欄位解析出來組合成 data_type.PostInfo
-            error_post_list = list()
-            del_post_list = list()
-            # PostAID = ""
-            _url = 'https://www.ptt.cc/bbs/'
-            index = str(newest_index)
-            if self.config.log_level == log.level.INFO:
-                PB = progressbar.ProgressBar(
-                    max_value=end_page - start_page + 1,
-                    redirect_stdout=True
-                )
-
-            def deleted_post(post_title):
-                if post_title.startswith('('):
-                    if '本文' in post_title:
-                        return data_type.post_delete_status.AUTHOR
-                    elif post_title.startswith('(已被'):
-                        return data_type.post_delete_status.MODERATOR
-                    else:
-                        return data_type.post_delete_status.UNKNOWN
-                else:
-                    return data_type.post_delete_status.NOT_DELETED
-
-            for index in range(start_page, newest_index + 1):
-                log.show_value(
-                    self.config,
-                    log.level.DEBUG,
-                    'CurrentPage',
-                    index
-                )
-
-                url = _url + board + '/index' + str(index) + '.html'
-                r = requests.get(url, cookies={'over18': '1'})
-                if r.status_code != requests.codes.ok:
-                    raise exceptions.NoSuchBoard(self.config, board)
-                soup = BeautifulSoup(r.text, 'html.parser')
-
-                for div in soup.select('div.r-ent'):
-                    web = div.select('div.title a')
-                    post = {
-                        'author': div.select('div.author')[0].text,
-                        'title': div.select('div.title')[0].text.strip('\n').strip(),
-                        'web': web[0].get('href') if web else ''
-                    }
-                    if post['title'].startswith('('):
-                        del_post_list.append(post['title'])
-                        if post['title'].startswith('(本文'):
-                            if '[' in post['title']:
-                                post['author'] = post['title'].split(
-                                    '[')[1].split(']')[0]
-                            else:
-                                post['author'] = post['title'].split('<')[
-                                    1].split('>')[0]
-                        else:
-                            post['author'] = post['title'].split('<')[
-                                1].split('>')[0]
-
-                    post = data_type.PostInfo(
-                        board=board,
-                        author=post['author'],
-                        title=post['title'],
-                        web_url='https://www.ptt.cc' + post['web'],
-                        delete_status=deleted_post(post['title'])
-                    )
-                    post_handler(post)
-
-                if self.config.log_level == log.level.INFO:
-                    PB.update(index - start_page)
-
-            log.show_value(
-                self.config,
-                log.level.DEBUG,
-                'DelPostList',
-                del_post_list
-            )
-
-            # 4. 把組合出來的 Post 塞給 handler
-
-            # 5. 顯示 progress bar
-            if self.config.log_level == log.level.INFO:
-                PB.finish()
-
-            return error_post_list, del_post_list
+            pass
+            # if self.config.host == data_type.host_type.PTT2:
+            #     raise exceptions.HostNotSupport(lib_util.get_current_func_name())
+            #
+            # # 網頁版本爬蟲
+            # # https://www.ptt.cc/bbs/index.html
+            #
+            # # 1. 取得總共有幾頁 MaxPage
+            # newest_index = self._get_newest_index(
+            #     data_type.index_type.WEB,
+            #     board=board)
+            # # 2. 檢查 StartPage 跟 EndPage 有沒有在 1 ~ MaxPage 之間
+            #
+            # check_value.check_index_range(
+            #     self.config,
+            #     'StartPage',
+            #     start_page,
+            #     'EndPage',
+            #     end_page,
+            #     max_value=newest_index
+            # )
+            #
+            # # 3. 把每篇文章(包括被刪除文章)欄位解析出來組合成 data_type.PostInfo
+            # error_post_list = list()
+            # del_post_list = list()
+            # # PostAID = ""
+            # _url = 'https://www.ptt.cc/bbs/'
+            # index = str(newest_index)
+            # if self.config.log_level == log.level.INFO:
+            #     PB = progressbar.ProgressBar(
+            #         max_value=end_page - start_page + 1,
+            #         redirect_stdout=True
+            #     )
+            #
+            # def deleted_post(post_title):
+            #     if post_title.startswith('('):
+            #         if '本文' in post_title:
+            #             return data_type.post_delete_status.AUTHOR
+            #         elif post_title.startswith('(已被'):
+            #             return data_type.post_delete_status.MODERATOR
+            #         else:
+            #             return data_type.post_delete_status.UNKNOWN
+            #     else:
+            #         return data_type.post_delete_status.NOT_DELETED
+            #
+            # for index in range(start_page, newest_index + 1):
+            #     log.show_value(
+            #         self.config,
+            #         log.level.DEBUG,
+            #         'CurrentPage',
+            #         index)
+            #
+            #     url = _url + board + '/index' + str(index) + '.html'
+            #     r = requests.get(url, cookies={'over18': '1'})
+            #     if r.status_code != requests.codes.ok:
+            #         raise exceptions.NoSuchBoard(self.config, board)
+            #     soup = BeautifulSoup(r.text, 'html.parser')
+            #
+            #     for div in soup.select('div.r-ent'):
+            #         web = div.select('div.title a')
+            #         post = {
+            #             'author': div.select('div.author')[0].text,
+            #             'title': div.select('div.title')[0].text.strip('\n').strip(),
+            #             'web': web[0].get('href') if web else ''
+            #         }
+            #         if post['title'].startswith('('):
+            #             del_post_list.append(post['title'])
+            #             if post['title'].startswith('(本文'):
+            #                 if '[' in post['title']:
+            #                     post['author'] = post['title'].split(
+            #                         '[')[1].split(']')[0]
+            #                 else:
+            #                     post['author'] = post['title'].split('<')[
+            #                         1].split('>')[0]
+            #             else:
+            #                 post['author'] = post['title'].split('<')[
+            #                     1].split('>')[0]
+            #
+            #         post = data_type.PostInfo(
+            #             board=board,
+            #             author=post['author'],
+            #             title=post['title'],
+            #             web_url='https://www.ptt.cc' + post['web'],
+            #             delete_status=deleted_post(post['title'])
+            #         )
+            #         post_handler(post)
+            #
+            #     if self.config.log_level == log.level.INFO:
+            #         PB.update(index - start_page)
+            #
+            # log.show_value(
+            #     self.config,
+            #     log.level.DEBUG,
+            #     'DelPostList',
+            #     del_post_list
+            # )
+            #
+            # # 4. 把組合出來的 Post 塞給 handler
+            #
+            # # 5. 顯示 progress bar
+            # if self.config.log_level == log.level.INFO:
+            #     PB.finish()
+            #
+            # return error_post_list, del_post_list
 
     def post(
             self,
@@ -1684,6 +1680,8 @@ class API:
         if not self._login_status:
             raise exceptions.Requirelogin(i18n.Requirelogin)
 
+        self.config.log_last_value = None
+
         new_password = new_password[:8]
 
         try:
@@ -1748,6 +1746,8 @@ class API:
         if not self._login_status:
             raise exceptions.Requirelogin(i18n.Requirelogin)
 
+        self.config.log_last_value = None
+
         check_value.check(self.config, str, 'board', board)
         self._check_board(board)
 
@@ -1758,6 +1758,76 @@ class API:
 
         return _api_get_bottom_post_list.get_bottom_post_list(self, board)
 
+    def del_post(
+            self,
+            board,
+            post_aid: str = None,
+            post_index: int = 0) -> None:
+        self._one_thread()
+
+        if not self._login_status:
+            raise exceptions.Requirelogin(i18n.Requirelogin)
+
+        self.config.log_last_value = None
+
+        check_value.check(self.config, str, 'Board', board)
+        if post_aid is not None:
+            check_value.check(self.config, str, 'PostAID', post_aid)
+        check_value.check(self.config, int, 'PostIndex', post_index)
+
+        if len(board) == 0:
+            raise ValueError(log.merge(
+                self.config,
+                [
+                    i18n.Board,
+                    i18n.ErrorParameter,
+                    board
+                ]))
+
+        if post_index != 0 and isinstance(post_aid, str):
+            raise ValueError(log.merge(
+                self.config,
+                [
+                    'PostIndex',
+                    'PostAID',
+                    i18n.ErrorParameter,
+                    i18n.BothInput
+                ]))
+
+        if post_index == 0 and post_aid is None:
+            raise ValueError(log.merge(
+                self.config,
+                [
+                    'PostIndex',
+                    'PostAID',
+                    i18n.ErrorParameter,
+                    i18n.NoInput
+                ]))
+
+        if post_index != 0:
+            newest_index = self._get_newest_index(
+                data_type.index_type.BBS,
+                board=board)
+            check_value.check_index(
+                self.config,
+                'PostIndex',
+                post_index,
+                newest_index)
+
+        board_info = self._check_board(board)
+
+        try:
+            from . import _api_del_post
+        except ModuleNotFoundError:
+            import _api_del_post
+
+        return _api_del_post.del_post(
+            self,
+            board_info,
+            board,
+            post_aid,
+            post_index)
+
     def _goto_board(self, board: str, refresh: bool = False, end: bool = False) -> None:
 
         cmd_list = list()
