@@ -190,6 +190,9 @@ SkipRegistrationForm = None
 url = None
 OnlySecureConnection = None
 CatchBottomPostSuccess = None
+ConfirmDelete = None
+DeleteSuccess = None
+DeletedPost = None
 
 
 def specific_load(input_language, lang_list):
@@ -1253,6 +1256,24 @@ def load(input_lang):
         'Catch bottom post success',
     ])
 
+    global ConfirmDelete
+    ConfirmDelete = specific_load(input_lang, [
+        '確定刪除',
+        'Confirm delete',
+    ])
+
+    global DeleteSuccess
+    DeleteSuccess = specific_load(input_lang, [
+        '刪除成功',
+        'Delete Success',
+    ])
+
+    global DeletedPost
+    DeletedPost = specific_load(input_lang, [
+        '已刪除文章',
+        'Deleted Post',
+    ])
+
     # No changes have been made to any settings
 
     # Quote original
